=========
Utilities
=========

-----------
Collections
-----------

dictionary_union
----------------

.. autofunction:: grundzeug.util.collections.dictionary_union

zip_equal
---------

.. autofunction:: grundzeug.util.collections.zip_equal

-------------
Documentation
-------------

set_module
----------

.. autofunction:: grundzeug.util.docs.set_module

---------
Sentinels
---------

make_sentinel
-------------

.. autofunction:: grundzeug.util.sentinels.make_sentinel